summaryrefslogtreecommitdiff
path: root/src/mongo/db/cancelable_operation_context.h
diff options
context:
space:
mode:
authorTyler Seip <Tyler.Seip@mongodb.com>2021-03-19 18:28:46 +0000
committerEvergreen Agent <no-reply@evergreen.mongodb.com>2021-03-23 17:37:22 +0000
commit8c463d0aa0cce19073210d274dcbb04c156dc802 (patch)
tree831640a2819370a0dc3641b02da5adad23e651a7 /src/mongo/db/cancelable_operation_context.h
parentf447e57dd2c5dbb39feef9cfe071ff1cc1de54d5 (diff)
downloadmongo-8c463d0aa0cce19073210d274dcbb04c156dc802.tar.gz
SERVER-53230: Rename cancelation -> cancellation everywhere
Diffstat (limited to 'src/mongo/db/cancelable_operation_context.h')
-rw-r--r--src/mongo/db/cancelable_operation_context.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/src/mongo/db/cancelable_operation_context.h b/src/mongo/db/cancelable_operation_context.h
index ca9493a58c2..ee4225e2b5b 100644
--- a/src/mongo/db/cancelable_operation_context.h
+++ b/src/mongo/db/cancelable_operation_context.h
@@ -38,28 +38,28 @@
namespace mongo {
-class CancelationToken;
+class CancellationToken;
class OperationContext;
/**
* Wrapper class around an OperationContext that calls markKilled(ErrorCodes::CallbackCanceled) when
* the supplied CancelationToken is canceled.
*
* This class is useful for having an OperationContext be interrupted when a CancelationToken is
* canceled. Note that OperationContext::getCancelationToken() is instead useful for having a
* CancelationToken be canceled when an OperationContext is interrupted. The combination of the two
* enables bridging between OperationContext interruption and CancelationToken cancellation
* arbitrarily.
*
* IMPORTANT: Executors are allowed to refuse work. markKilled(ErrorCodes::CallbackCanceled) won't
* be called when the supplied CancelationToken is canceled if the task executor has already been
* shut down, for example. Use a task executor bound to the process lifetime if you must guarantee
* that the OperationContext is interrupted when the CancelationToken is canceled.
*/
class CancelableOperationContext {
public:
CancelableOperationContext(ServiceContext::UniqueOperationContext opCtx,
- const CancelationToken& cancelToken,
+ const CancellationToken& cancelToken,
ExecutorPtr executor);
CancelableOperationContext(const CancelableOperationContext&) = delete;
@@ -38,28 +38,28 @@
/**
* Wrapper class around an OperationContext that calls markKilled(ErrorCodes::CallbackCanceled) when
- * the supplied CancelationToken is canceled.
+ * the supplied CancellationToken is canceled.
*
@@ -38,28 +38,28 @@
*
- * This class is useful for having an OperationContext be interrupted when a CancelationToken is
- * canceled. Note that OperationContext::getCancelationToken() is instead useful for having a
- * CancelationToken be canceled when an OperationContext is interrupted. The combination of the two
- * enables bridging between OperationContext interruption and CancelationToken cancellation
+ * This class is useful for having an OperationContext be interrupted when a CancellationToken is
+ * canceled. Note that OperationContext::getCancellationToken() is instead useful for having a
+ * CancellationToken be canceled when an OperationContext is interrupted. The combination of the two
+ * enables bridging between OperationContext interruption and CancellationToken cancellation
* arbitrarily.
*
@@ -38,28 +38,28 @@
*
* IMPORTANT: Executors are allowed to refuse work. markKilled(ErrorCodes::CallbackCanceled) won't
- * be called when the supplied CancelationToken is canceled if the task executor has already been
+ * be called when the supplied CancellationToken is canceled if the task executor has already been
* shut down, for example. Use a task executor bound to the process lifetime if you must guarantee
@@ -38,28 +38,28 @@
* shut down, for example. Use a task executor bound to the process lifetime if you must guarantee
- * that the OperationContext is interrupted when the CancelationToken is canceled.
+ * that the OperationContext is interrupted when the CancellationToken is canceled.
*/
class CancelableOperationContext {